@@ -3,49 +3,33 @@ package t::util;
 use Carp;
 use FindBin;
 use File::Basename qw(fileparse);
-use File::Spec;
 use Cwd qw(cwd);
 use Test::More;
-use Test::Deep qw(cmp_details deep_diag methods set);
+use Test::Deep;
+# Test::Deep doesn't export cmp_details, deep_diag until recent version (0.104)
+# so we import them "by hand"
+*cmp_details=\&Test::Deep::cmp_details;
+*deep_diag=\&Test::Deep::deep_diag;
 use Exporter();
 use strict;
 
 our @ISA=qw(Exporter);
-our @EXPORT=qw(script scriptpath scriptfullpath scriptbasename scriptcode scripthead 
-	       subtestdir rootpath
-	       as_bool as_list flatten
-	       is_quietly is_loudly cmp_quietly cmp_set_quietly cmp_bag_quietly cmp_attrs 
-	       report report_pass report_fail 
-	       called_from callers diag_callers group val2idx
+our @EXPORT=qw(script scriptpath scriptfullpath scriptbasename scriptcode rootpath
+	       as_bool flatten
+	       cmp_quietly cmp_attrs report report_pass report_fail
 	     );
-our($SCRIPT,$SCRIPTPATH,$SCRIPTBASENAME,$SCRIPTCODE,$SCRIPTHEAD,$ROOTPATH);
+our($SCRIPT,$SCRIPTPATH,$SCRIPTBASENAME,$SCRIPTCODE,$ROOTPATH);
 sub script {$SCRIPT or (($SCRIPT,$SCRIPTPATH)=fileparse($0) and $SCRIPT);}
 sub scriptpath {$SCRIPTPATH or (($SCRIPT,$SCRIPTPATH)=fileparse($0) and $SCRIPTPATH);}
 sub scriptfullpath {$FindBin::Bin}
 sub scriptbasename {$SCRIPTBASENAME or 
 		      (($SCRIPTBASENAME)=fileparse($0,qw(.t)) and $SCRIPTBASENAME);}
-sub scriptcode {$SCRIPTCODE or ((($SCRIPTCODE)=script=~/\.(\w+)\.t$/)[0] and $SCRIPTCODE);}
-sub scripthead {$SCRIPTHEAD or (($SCRIPTHEAD)=script=~/^(.*?)\.\d+/ and $SCRIPTHEAD);}
-sub subtestdir {File::Spec->catdir(scriptpath,scriptbasename)}
+sub scriptcode {$SCRIPTCODE or (($SCRIPTCODE)=script=~/\.(\w+)\.t$/)[0];}
 sub rootpath {$ROOTPATH or $ROOTPATH=cwd}
 
 sub as_bool {$_[0]? 1: 0}
-sub as_list {my $list=@_>1? [@_]: (ref $_[0]? $_[0]: ([split(/\s+/,$_[0])]))}
 sub flatten {map {'ARRAY' eq ref $_? @$_: $_} @_}
 
-# like is but reports errors the way we want
-sub is_loudly {
-  my($actual,$correct,$label,$file,$line)=@_;
-  my $ok=$actual eq $correct;
-  pass($label), return 1 if $ok;
-  report_fail($ok,"$label: expected $correct, got $actual",$file,$line);
-}
-# like is but reports errors the way we want
-sub is_quietly {
-  my($actual,$correct,$label,$file,$line)=@_;
-  report_fail($actual eq $correct,"$label: expected $correct, got $actual",$file,$line);
-}
-
 # like cmp_deeply but reports errors the way we want
 sub cmp_quietly {
   my($actual,$correct,$label,$file,$line)=@_;
@@ -54,16 +38,6 @@ sub cmp_quietly {
   my($ok,$details)=cmp_details($actual,$correct);
   report_fail($ok,"$label",$file,$line,$details);
 }
-# like cmp_set but reports errors the way we want
-sub cmp_set_quietly {
-  my($actual,$correct,$label,$file,$line)=@_;
-  cmp_quietly($actual,Test::Deep::set(@$correct),$label,$file,$line);
-}
-# like cmp_bag but reports errors the way we want
-sub cmp_bag_quietly {
-  my($actual,$correct,$label,$file,$line)=@_;
-  cmp_quietly($actual,Test::Deep::bag(@$correct),$label,$file,$line);
-}
 # $actual is object. $correct is HASH of attr=>value pairs wih Test::Deep decorations
 sub cmp_attrs {
   my($actual,$correct,$label,$file,$line)=@_;
@@ -101,17 +75,8 @@ sub report_fail {
   }
   return 0;
 }
-# emit stack trace - $callers set by callers function below
-sub diag_callers {
-  my($callers)=@_;
-  return unless @$callers;
-  for my $caller (@$callers) {
-    my($package,$file,$line)=@$caller;
-    diag("from $file line $line");
-  }
-}
 
-# set ($file,$line) to last (lowest) caller in main if not already set
+# set $file,$line if not already set
 sub called_from {
   return @_ if $_[0];
   my($package,$file,$line);
@@ -121,49 +86,6 @@ sub called_from {
   }
   ($file,$line);
 }
-# set $callers if not already set 
-# $what controls what is reported: 
-#  default - 'mqin' - all callers in main
-#  'all' - entire stack trace
-#  'main' all callers in main
-#  'top' - 1st caller in main
-#  'last' - last caller in main - same as default
-# in scalar context, returns ARRAY of ARRAYs [$package,$file,$line]
-# in array context: default, 'top', 'last' return ($file,$line)
-#                   others return array of ARRAYs [$package,$file,$line]
-sub callers {
-  # figure out arguments: 
-  my($callers,$what,$package,$file,$line);
-  if (@_ && 'ARRAY' eq ref $_[0]) {
-    # arg is $callers
-    ($callers,$what)=@_;
-    $callers=undef unless @$callers; # empty $callers same as not set
-  } elsif (@_==2 && !ref $_[0]) {
-    # args are $file,$line
-    ($file,$line)=@_;
-    $callers=[[undef,$file,$line]] if defined $file;
-  } elsif (@_>2 && !ref $_[0]) {
-    # args are $file,$line,$what
-    ($file,$line,$what)=@_;
-    $callers=[[undef,$file,$line]] if defined $file;
-  }
-  $what='main' unless defined $what;
-  unless (defined $callers) {
-    $callers=[];
-    my $i=0;
-    while (($package,$file,$line)=caller($i++)) {
-      $callers=[[$package,$file,$line]], last if $what eq 'last' && $package eq 'main';
-      push(@$callers,[$package,$file,$line]) 
-	if $what eq 'all' || ($what eq 'main' && $package eq 'main');
-    }
-    $callers=[[$package,$file,$line]] if $what eq 'top';
-  }
-  if (wantarray && ($what eq 'top' || $what eq 'last')) {
-    ($package,$file,$line)=@{$callers->[0]};
-    return ($file,$line);
-  }
-  wantarray? @$callers: $callers;
-}
 
 ################################################################################
 # code below here is mostly from other modules
@@ -171,25 +93,18 @@ sub callers {
 ################################################################################
 
 # # TODO: rewrite w/ Hash::AutoHash::MultiValued
-# group a list by categories returned by sub.
-# has to be declared before use, because of prototype
-sub group (&@) {
-  my($sub,@list)=@_;
-  my %groups;
-  for (@list) {
-    my $group=&$sub($_);
-    my $members=$groups{$group} || ($groups{$group}=[]);
-    push(@$members,$_);
-  }
-  wantarray? %groups: \%groups;
-}
-# produce hash mapping each element of list to its position. doesn't worry about duplicates
-sub val2idx {
-  my $i=0;
-  my %val2idx=map {$_=>$i++} @_;
-  wantarray? %val2idx: \%val2idx;
-}
-
+# # group a list by categories returned by sub.
+# # has to be declared before use, because of prototype
+# sub group (&@) {
+#   my($sub,@list)=@_;
+#   my %groups;
+#   for (@list) {
+#     my $group=&$sub($_);
+#     my $members=$groups{$group} || ($groups{$group}=[]);
+#     push(@$members,$_);
+#   }
+#   wantarray? %groups: \%groups;
+# }
 # # like group, but processes elements that are put on list. 
 # # sub should return 2 element list: 1st defines group, 2nd maps the value
 # # has to be declared before use, because of prototype
